@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: m3Func.php 2827 2010-02-04 03:41:15Z fishbone $
+ * @version    SVN: $Id: m3Func.php 3263 2010-06-19 08:11:42Z fishbone $
  * @link       http://www.magic3.org
  */
 /**
@@ -130,6 +130,20 @@ function makeTruncStr($str, $len)
 	}
 	return $destStr;
 }
+/**
+ * 文字数を取得
+ *
+ * @param string  $str		対象文字列
+ * @return int				文字数
+ */
+function getLetterCount($str)
+{
+	if (function_exists('mb_strlen')){
+		return mb_strlen($str);
+	} else {
+		return strlen($str);
+	}
+}
 /**
  * メールアドレスの取り出し
  *
@@ -219,6 +233,21 @@ function fgetByCsv(&$fp, $delimType = 0, $encode = '')
 		return $values;
 	}
 }
+/**
+ * ファイルの拡張子を取得
+ *
+ * @param string $path	ファイルパス
+ * @return string		拡張子
+ */
+function getExtension($path)
+{
+	if (function_exists('mb_ereg')){
+		if (mb_ereg('^.*\.([^\.]*)$', $path, $part)) return strtolower($part[1]);
+	} else {
+		if (preg_match('/^.*\.([^\.]*)$/', $path, $part)) return strtolower($part[1]);
+	}
+	return '';
+}
 /**
  * ディレクトリ内のファイル一覧の取得
  *
