@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: envManager.php 3160 2010-05-27 03:11:55Z fishbone $
+ * @version    SVN: $Id: envManager.php 3301 2010-06-27 10:53:46Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/common/version.php');	// システムバージョンクラス
@@ -41,6 +41,7 @@ class EnvManager extends Core
  	private $db;				// DBオブジェクト
 	private $canUseDbSession;	// DBセッションが使用できるかどうか
 	private $canUseDb;			// DBが使用可能状態にあるかどうか
+	private $canUseCookie;		// クッキーが使用可能かどうか
 	private $mobileUseSession;	// 携帯でセッション管理を使用するかどうか
 	private $canChangeLang;		// 言語変更可能かどうか
 	private $useSsl;			// SSL機能を使用するかどうか
@@ -54,6 +55,7 @@ class EnvManager extends Core
 	private $isPcSite;			// PC用URLアクセスかどうか
 	private $isMobileSite;		// 携帯用URLアクセスかどうか
 	private $isSmartphoneSite;	// スマートフォン用URLへのアクセスかどうか
+	private $isSubWidget;		// サブウィジェットの起動かどうか
 	private $isMaintenance;		// メンテナンスモードかどうか
 	private $isServerConnector;	// サーバ接続かどうか
 	private $mobileEncoding;	// 携帯用の入力、出力エンコーディング
@@ -1597,13 +1599,14 @@ class EnvManager extends Core
 	 * ・セッションID
 	 * ・ドコモ端末の場合はiモードID受信用のパラメータを付加
 	 *
-	 * @param string,array	$addParam 追加パラメータ
+	 * @param string,array	$addParam		追加パラメータ
+	 * @param bool          $withSessionId	セッションIDを付加するかどうか
 	 * @return string		作成したURL
 	 */
-	public function createCurrentPageUrlForMobile($addParam='')
+	public function createCurrentPageUrlForMobile($addParam = '', $withSessionId = true)
 	{
 		// 携帯用パラメータ取得
-		$param = $this->_getMobileUrlParam();
+		$param = $this->_getMobileUrlParam($withSessionId);
 		
 		// ページサブID付加
 		$param['sub'] = $this->getCurrentPageSubId();
@@ -1734,6 +1737,25 @@ class EnvManager extends Core
 	{
 		return $this->canUseDb;
 	}
+	/**
+	 * クッキーが使用可能かどうかを設定
+	 *
+	 * @param bool			true=使用可、false=使用不可
+	 * @return				なし
+	 */
+	public function setCanUseCookie($value)
+	{
+		$this->canUseCookie = $value;
+	}
+	/**
+	 * クッキーが使用可能かどうか
+	 *
+	 * @return bool			true=使用可、false=使用不可
+	 */
+	public function canUseCookie()
+	{
+		return $this->canUseCookie;
+	}
 	/**
 	 * Timestamp型データの初期値を取得
 	 *
@@ -1988,7 +2010,7 @@ class EnvManager extends Core
 	/**
 	 * スマートフォン用URLへのアクセスかどうかを設定
 	 *
-	 * @param bool $status			true=スマートフォン用URLへのアクセ、false=スマートフォン用URL以外へのアクセス
+	 * @param bool $status			true=スマートフォン用URLへのアクセス、false=スマートフォン用URL以外へのアクセス
 	 * @return 			なし
 	 */
 	public function setIsSmartphoneSite($status)
@@ -2004,6 +2026,25 @@ class EnvManager extends Core
 	{
 		return $this->isSmartphoneSite;
 	}
+	/**
+	 * サブウィジェットの起動かどうかを設定
+	 *
+	 * @param bool $status			true=サブウィジェットでの起動、false=通常のウィジェット起動
+	 * @return 			なし
+	 */
+	public function setIsSubWidget($status)
+	{
+		$this->isSubWidget = $status;
+	}
+	/**
+	 * サブウィジェットの起動かどうか
+	 *
+	 * @return bool		true=サブウィジェットでの起動、false=通常のウィジェット起動
+	 */
+	public function getIsSubWidget()
+	{
+		return $this->isSubWidget;
+	}
 	/**
 	 * サーバ接続かどうかを設定
 	 *
@@ -2075,9 +2116,10 @@ class EnvManager extends Core
 	/**
 	 * 携帯用のURLパラメータを取得
 	 *
-	 * @return array			URLパラメータ
+	 * @param bool   $withSessionId	セッションIDを付加するかどうか
+	 * @return array				URLパラメータ
 	 */
-	function _getMobileUrlParam()
+	function _getMobileUrlParam($withSessionId = true)
 	{
 		global $gInstanceManager;
 		
@@ -2088,7 +2130,7 @@ class EnvManager extends Core
 				// ログインしている場合はセッションIDを付加(セッション管理機能が使用可能なときのみ)
 				//if (!empty($this->mobileUseSession) && $this->isCurrentUserLogined()) $param[session_name()] = session_id();
 				// ログイン状況に関わらずセッションIDを付加(セッション管理機能が使用可能なときのみ)
-				if (!empty($this->mobileUseSession)) $param[session_name()] = session_id();
+				if ($withSessionId && !empty($this->mobileUseSession)) $param[session_name()] = session_id();
 					
 				// ドコモ端末の場合はiモードIDを送信させる
 				if ($agent->isDoCoMo()) $param['guid'] = 'ON';
