@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2009 Magic3 Project.
+ * @copyright  Copyright 2006-2010 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainMenudefWidgetContainer.php 2732 2009-12-24 01:31:40Z fishbone $
+ * @version    SVN: $Id: admin_mainMenudefWidgetContainer.php 3131 2010-05-14 07:07:41Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainBaseWidgetContainer.php');
@@ -26,6 +26,7 @@ class admin_mainMenudefWidgetContainer extends admin_mainBaseWidgetContainer
 	private $isExistsMenuItem;		// メニュー項目が存在するかどうか
 	private $menuId;		// 現在選択中のメニューID
 	private $menuItemType;	// メニュー項目タイプ
+	private $menuDeviceType;	// メニューの端末タイプ
 	private $itemTypeArray;		// メニュー項目の種類
 	const MAIN_MENU_ID = 'main_menu';			// メインメニューID
 	const CONTENT_WIDGET_ID = 'default_content';			// コンテンツ編集ウィジェット
@@ -34,6 +35,9 @@ class admin_mainMenudefWidgetContainer extends admin_mainBaseWidgetContainer
 	const FOLDER_ICON_FILE = '/images/system/folder.png';		// フォルダアイコン
 	const ICON_SIZE = 16;		// アイコンのサイズ
 	const WIDGET_TYPE_MENU = 'menu';		// メニュー型のウィジェット(キャッシュクリア用)
+	const CONTENT_TYPE_PC = '';			// 汎用コンテンツのコンテンツタイプ(PC用)
+	const CONTENT_TYPE_MOBILE = 'mobile';			// 汎用コンテンツのコンテンツタイプ(携帯用)
+	const CONTENT_TYPE_SMARTPHONE = 'smartphone';			// 汎用コンテンツのコンテンツタイプ(スマートフォン用)
 	
 	/**
 	 * コンストラクタ
@@ -111,6 +115,11 @@ class admin_mainMenudefWidgetContainer extends admin_mainBaseWidgetContainer
 		$this->menuId = $request->trimValueOf('menuid');		// 現在選択中のメニュータイプ
 		if ($this->menuId == '') $this->menuId = self::MAIN_MENU_ID;		// デフォルトは通常のメニュー
 		
+		// メニューの端末タイプを取得
+		$this->menuDeviceType = 0;	// メニューの端末タイプ
+		$ret = $this->db->getMenuId($this->menuId, $row);
+		if ($ret) $this->menuDeviceType = $row['mn_device_type'];
+
 		$act = $request->trimValueOf('act');
 		$parentId = $request->trimValueOf('parentid');		// 親メニューID取得
 		if ($parentId == '') $parentId = '0';
@@ -195,6 +204,10 @@ class admin_mainMenudefWidgetContainer extends admin_mainBaseWidgetContainer
 		$url = $request->trimValueOf('item_url');		// 決定したURL
 		$url = str_replace($this->gEnv->getRootUrl(), M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END, $url);// マクロ変換
 		
+		$this->menuDeviceType = 0;	// メニューの端末タイプ
+		$ret = $this->db->getMenuId($this->menuId, $row);
+		if ($ret) $this->menuDeviceType = $row['mn_device_type'];
+		
 		$reloadData = false;		// データの再読み込み
 		if ($act == 'add'){// 新規追加
 			// 入力チェック
@@ -284,6 +297,7 @@ class admin_mainMenudefWidgetContainer extends admin_mainBaseWidgetContainer
 		$url = str_replace(M3_TAG_START . M3_TAG_MACRO_ROOT_URL . M3_TAG_END, $this->gEnv->getRootUrl(), $url);		// マクロ展開
 		
 		$contentType = '';		// コンテンツタイプ(ページ属性)
+		$contType = '';			// 汎用コンテンツのコンテンツタイプ
 		if ($this->currentPageSubId == '_root'){
 			$this->tmpl->setAttribute('input_no_url', 'visibility', 'visible');// URL非表示データ
 			$this->tmpl->addVar('_widget', 'root_selected', 'selected');		// ページサブID選択
@@ -303,9 +317,25 @@ class admin_mainMenudefWidgetContainer extends admin_mainBaseWidgetContainer
 				if ($ret){
 					$contentType = $row['pn_content_type'];
 				}
-
+				// メニューの端末タイプごとのアクセスポイントを取得
+				// 汎用コンテンツのコンテンツタイプを取得
+				switch ($this->menuDeviceType){
+					case 0:			// PC用
+					default:
+						$url = $this->gEnv->getDefaultUrl();
+						$contType = self::CONTENT_TYPE_PC;			// 汎用コンテンツのコンテンツタイプ
+						break;
+					case 1:			// 携帯用
+						$url = $this->gEnv->getDefaultMobileUrl();
+						$contType = self::CONTENT_TYPE_MOBILE;			// 汎用コンテンツのコンテンツタイプ
+						break;
+					case 2:			// スマートフォン用
+						$url = $this->gEnv->getDefaultSmartphoneUrl();
+						$contType = self::CONTENT_TYPE_SMARTPHONE;			// 汎用コンテンツのコンテンツタイプ
+						break;
+				}
+				
 				// 表示データタイプごとの処理
-				$url = $this->gEnv->getDefaultUrl();
 				switch ($contentType){
 					case M3_VIEW_TYPE_CONTENT:				// 汎用コンテンツ
 						$this->contentId = $paramArray[M3_REQUEST_PARAM_CONTENT_ID];
@@ -327,7 +357,7 @@ class admin_mainMenudefWidgetContainer extends admin_mainBaseWidgetContainer
 		switch ($contentType){
 			case M3_VIEW_TYPE_CONTENT:				// 汎用コンテンツ
 				$this->tmpl->setAttribute('sel_content', 'visibility', 'visible');// コンテンツ選択メニュー表示
-				$this->db->getVisibleAllContents(array($this, 'contentListLoop'), $langId);
+				$this->db->getVisibleAllContents($langId, $contType, array($this, 'contentListLoop'));
 				break;
 			case M3_VIEW_TYPE_PRODUCT:				// 製品
 				break;
@@ -620,7 +650,8 @@ class admin_mainMenudefWidgetContainer extends admin_mainBaseWidgetContainer
 				// コンテンツの編集ボタンの有効状態
 				$enableContentLink = '';
 				if (empty($contentId)) $enableContentLink = 'disabled';
-		
+				if ($this->menuDeviceType == 2) $enableContentLink = 'disabled';	// メニューがスマートフォン用のときはコンテンツ編集可能にしない
+				
 				$itemRow = array(
 					'index' => $index,													// 行番号
 					'serial' => $serial,			// シリアル番号
